Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Set ¶
type Set struct {
// contains filtered or unexported fields
}
func (*Set) AllExists ¶
AllExists tests the specified items for membership in the set. Returns true if all items are members of the set, false otherwise.
func (*Set) Delete ¶
func (s *Set) Delete(items ...interface{})
Delete removes the specified items from the set.
Click to show internal directories.
Click to hide internal directories.